//*************************************************************
//  File name: xpanddlg.c
//
//  Dialog boxes like the Color dialog box in the common dialogs expand and 
//  contract after they are created. This sample shows how this is done. 
//
//  The method used here is to create the dialog box at the full or expanded
//  size and in the WM_INITDIALOG, it is reduced to the required size using
//  MoveWindow(). The dialog box is also expanded using MoveWindow.
//
//  Description:
//      WinMain and window procedure routines.
//
//  History:    Date       Author     Comment
//              1/1/92     JJJ        Created
//
// Written by Microsoft Product Support Services, Windows Developer Support
// Copyright (c) 1992 Microsoft Corporation. All rights reserved.
//*************************************************************

#include "global.h"

HANDLE ghInst = NULL;
HWND ghWndMain = NULL;

char szMainMenu[] = "MainMenu";
char szMainClass[] = "MainClass";
char szInstructions[] =
"Dialog boxes like the COMMONDLG's color dialog \
expands and contracts. This sample demonstrates a techniques used to do \
this. To run the sample, choose the Run Test option in the menu.";
//*************************************************************
//
//  WinMain()
//
//  Purpose:
//      Entry point for all Windows applications.
//
//  Parameters:
//      HANDLE hInstance     - Handle to current instance
//      HANDLE hPrevInstance - Handle to previous instance
//      LPSTR  lpCmdLine     - Command-line arguments
//      int    nCmdShow      - How window is initially displayed
//
//  Return: (int PASCAL)
//
//  Comments:
//
//  History:    Date       Author     Comment
//              1/1/92   JJJ        Created
//
//*************************************************************

int PASCAL WinMain (HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
   MSG msg;

   if (!hPrevInstance && !InitApplication(hInstance))
      return (FALSE);

   if (!InitInstance(hInstance, nCmdShow))
      return (FALSE);

   while (GetMessage(&msg, NULL, NULL, NULL))
   {
      TranslateMessage(&msg);
      DispatchMessage(&msg);
   }
   return (msg.wParam);
}   /* WinMain() */

//*************************************************************
//
//  MainWndProc()
//
//  Purpose:
//      Main Window procedure.
//
//  Parameters:
//      HWND     hWnd   - Handle to main window
//      unsigned msg    - Message passed to application
//      WORD     wParam - Additional message information
//      LONG     lParam - Additional message information
//
//  Return: (LONG FAR PASCAL)
//
//  Comments:
//
//  History:    Date       Author     Comment
//              1/1/92   JJJ        Created
//
//*************************************************************

LONG FAR PASCAL MainWndProc (HWND hWnd, unsigned msg, WORD wParam, LONG lParam)
{
   FARPROC lpProc;

   switch (msg)
   {
      case WM_COMMAND:
         switch (wParam)
         {
            case IDM_ABOUT:  // About box
               lpProc = MakeProcInstance(About, ghInst);
               DialogBox(ghInst, "AboutBox", hWnd, lpProc);
               FreeProcInstance(lpProc);
               break;

            case IDM_TEST:   // the expanding dialog box
               lpProc = MakeProcInstance(ExpandDlgProc, ghInst);
               DialogBox(ghInst, "Expand", hWnd, lpProc);
               FreeProcInstance(lpProc);
               break;

            case IDM_INSTRUCTIONS:     // the instructions dialog box
               lpProc = MakeProcInstance(Instructions, ghInst);
               DialogBox(ghInst, "Instructions", hWnd, lpProc);
               FreeProcInstance(lpProc);
               break;
         }
         break;

      case WM_DESTROY:
         PostQuitMessage(0);
         break;
   }
   return (DefWindowProc(hWnd, msg, wParam, lParam));
}   /* MainWndProc() */

//*************************************************************
//
//  About()
//
//  Purpose:
//      The About dialog box procedure.
//
//  Parameters:
//      HWND     hDlg   - Handle to dialog window
//      unsigned msg    - Message passed to dialog window
//      WORD     wParam - Additional message information
//      LONG     lParam - Additional message information
//
//  Return: (BOOL FAR PASCAL)
//      TRUE  - About dialog procedure handled the message.
//      FALSE - About dialog procedure did not handle the message.
//
//  Comments:
//
//  History:    Date       Author     Comment
//              1/1/92   JJJ        Created
//
//*************************************************************

BOOL FAR PASCAL About (HWND hDlg, unsigned msg, WORD wParam, LONG lParam)
{
   switch (msg)
   {
      case WM_INITDIALOG:
         SetDlgItemText(hDlg, ID_DESC, "Expanding Dialogboxes");
         SetDlgItemText(hDlg, ID_VER, "Version 1.0");
         return (TRUE);

      case WM_COMMAND:
         switch (wParam)
         {
            case IDOK:

            case IDCANCEL:
               EndDialog(hDlg, TRUE);
               return (TRUE);

            default:
               break;
         }
         break;
   }
   return (FALSE); // Didn't process a message
}   /* About() */

//*************************************************************
//
//  ExpandDlgProc()
//
//  Purpose:
//      The Expand dialog box procedure.
//      Toggles dialog box between reduced and expanded when the 
//      ID_MORE button is hit.  When the button is hit, the 
//      dialog box is resized with MoveWindow,  and the button
//      text is updated.
//
//  Parameters:
//      HWND     hDlg   - Handle to dialog window
//      unsigned msg    - Message passed to dialog window
//      WORD     wParam - Additional message information
//      LONG     lParam - Additional message information
//
//  Return: (BOOL FAR PASCAL)
//      TRUE  - Expand dialog procedure handled the message.
//      FALSE - Expand dialog procedure did not handle the message.
//
//  Comments:
//      The two static variables wNormalHeight and wExpandedHeight
//      hold the two heights. These are calculated in the WM_INITDIALOG.
//      The wExpandedHeight is the height defined in the .rc file. The 
//      wNormalHeight is couple of pixels below the "More Choices.. " 
//      button. 
//
//  History:    Date       Author     Comment
//              1/1/92   JJJ        Created
//
//*************************************************************

BOOL FAR PASCAL ExpandDlgProc (HWND hDlg, unsigned msg, WORD wParam, LONG lParam)
{
   static WORD wNormalHeight;     // height of reduced dialog box (which
                                  // extends just past the ID_MORE button vertically)
   static WORD wExpandedHeight;   // height of full size dialog box
   static BOOL fExpanded = FALSE;

   switch (msg)
   {
      case WM_INITDIALOG:
      {
         RECT rDlg, rButton;

         // Resize the dialog box so it extends just past the 
         // ID_MORE button vertically.  Keep the upper left 
         // coordinates and the width the same.

         GetWindowRect(hDlg, &rDlg);
         wExpandedHeight = rDlg.bottom - rDlg.top;

         GetWindowRect(GetDlgItem(hDlg, ID_MORE), &rButton);
         wNormalHeight = rButton.bottom - rDlg.top + GetSystemMetrics(SM_CYFRAME) * 3;

         MoveWindow(hDlg, rDlg.left, rDlg.top, rDlg.right - rDlg.left, wNormalHeight, TRUE);
         return (TRUE);
      }

      case WM_COMMAND:
         switch (wParam)
         {
            case ID_MORE:
               if (fExpanded)     // already expanded - so reduce it
               {
                  RECT rDlg;

                  // change only the height of the dialog box 

                  GetWindowRect(hDlg, &rDlg);
                  MoveWindow(hDlg, rDlg.left, rDlg.top, rDlg.right - rDlg.left, wNormalHeight, TRUE);

                  // change ID_MORE button text
                  SetWindowText(GetDlgItem(hDlg, ID_MORE), "&More Choices ......");

                  fExpanded = FALSE;
               }
               else     // not expanded - so expand it
               {
                  RECT rDlg;

                  // change only the height of the dialog box 

                  GetWindowRect(hDlg, &rDlg);
                  MoveWindow(hDlg, rDlg.left, rDlg.top, rDlg.right - rDlg.left, wExpandedHeight, TRUE);

                  // change ID_MORE button text
                  SetWindowText(GetDlgItem(hDlg, ID_MORE), "&Close Extra ......");

                  fExpanded = TRUE;
               }
               break;

            case IDOK:

            case IDCANCEL:
               EndDialog(hDlg, TRUE);
               return (TRUE);

            default:
               break;
         }
         break;
   }
   return (FALSE); // Didn't process a message
}   // ExpandDlgProc() 

//*************************************************************
//
//  Instructions()
//
//  Purpose:
//      The instructions dialog box procedure.
//
//  Parameters:
//      HWND     hDlg   - Handle to dialog window
//      unsigned msg    - Message passed to dialog window
//      WORD     wParam - Additional message information
//      LONG     lParam - Additional message information
//
//  Return: (BOOL FAR PASCAL)
//      TRUE  - dialog procedure handled the message.
//      FALSE - dialog procedure did not handle the message.
//
//  Comments:
//
//  History:    Date       Author     Comment
//              1/1/92   JJJ        Created
//
//*************************************************************

BOOL FAR PASCAL Instructions (HWND hDlg, unsigned msg, WORD wParam, LONG lParam)
{
   static HFONT hFont;

   switch (msg)
   {
      case WM_INITDIALOG:
      {
         /*   Height = (points_size/72 points per inch) * (GetDeviceCaps(LOGPIXELSY)= pixels per inch)*/
         HDC hDC;
         int Height;

         hDC = GetDC(hDlg);
         Height = ((GetDeviceCaps(hDC, LOGPIXELSY) * 16) / 72);

         hFont = CreateFont(Height, 0, 0, 0, FW_BOLD, 0, 0, 0, ANSI_CHARSET, OUT_DEFAULT_PRECIS,
                            CLIP_DEFAULT_PRECIS, DEFAULT_QUALITY, FF_DONTCARE, (LPSTR)"Roman");
         ReleaseDC(hDlg, hDC);
         SetDlgItemText(hDlg, ID_TITLE, "Purpose");
         SetWindowText(GetDlgItem(hDlg, ID_INSTBOX), (LPSTR)szInstructions);
         SendDlgItemMessage(hDlg, ID_TITLE, WM_SETFONT, hFont, TRUE);
         return (TRUE);
      }

      case WM_COMMAND:
         if (wParam == IDOK || wParam == IDCANCEL)
         {
            EndDialog(hDlg, TRUE);
            DeleteObject(hFont);
            return (TRUE);
         }
         break;
   }
   return (FALSE); // Didn't process a message
}   /* Instructions() */
/*** EOF: xpanddlg.c ***/
